import RDSDataService from 'aws-sdk/clients/rdsdataservice';
import _createAdapter from 'resolve-storage-base';
import connect from './connect';
import loadEventsByCursor from './load-events-by-cursor';
import loadEventsByTimestamp from './load-events-by-timestamp';
import freeze from './freeze';
import unfreeze from './unfreeze';
import getLatestEvent from './get-latest-event';
import saveEvent from './save-event';
import init from './init';
import drop from './drop';
import dispose from './dispose';
import fullJitter from './full-jitter';
import executeStatement from './execute-statement';
import saveEventOnly from './save-event-only';
import paginateEvents from './paginate-events';
import coercer from './coercer';
import escapeId from './escape-id';
import escape from './escape';
import shapeEvent from './shape-event';
import _createResource from './resource/create';
import _disposeResource from './resource/dispose';
import _destroyResource from './resource/destroy';

const createAdapter = _createAdapter.bind(null, {
  connect,
  loadEventsByCursor,
  loadEventsByTimestamp,
  getLatestEvent,
  saveEvent,
  init,
  drop,
  dispose,
  freeze,
  unfreeze,
  RDSDataService,
  escapeId,
  escape,
  fullJitter,
  executeStatement,
  saveEventOnly,
  paginateEvents,
  coercer,
  shapeEvent
});

export default createAdapter;
const pool = {
  executeStatement,
  connect,
  RDSDataService,
  escapeId,
  escape,
  fullJitter,
  coercer,
  dispose,
  shapeEvent
};

const createResource = _createResource.bind(null, pool);

const disposeResource = _disposeResource.bind(null, pool);

const destroyResource = _destroyResource.bind(null, pool);

Object.assign(pool, {
  createResource,
  disposeResource,
  destroyResource
});
export { createResource as create, disposeResource as dispose, destroyResource as destroy };
//# sourceMappingURL=index.js.map