"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _constants = require("./constants");

const saveEventOnly = async function (pool, event) {
  const {
    databaseName,
    tableName,
    executeStatement,
    escapeId,
    escape
  } = pool;
  const serializedEvent = [`${escape(event.aggregateId)},`, `${+event.aggregateVersion},`, `${escape(event.type)},`, escape(JSON.stringify(event.payload != null ? event.payload : null))].join('');

  const byteLength = Buffer.byteLength(serializedEvent) + _constants.RESERVED_EVENT_SIZE;

  const databaseNameAsId = escapeId(databaseName);
  const threadsTableAsId = escapeId(`${tableName}-threads`);
  const eventsTableAsId = escapeId(tableName);

  while (true) {
    try {
      // prettier-ignore
      await executeStatement(`WITH "random_thread_id" AS (
          SELECT "threadId"
          FROM ${databaseNameAsId}.${threadsTableAsId}
          OFFSET FLOOR(Random() * 256)
          LIMIT 1
        ), "vector_id" AS (
          SELECT "threadId", "threadCounter"
          FROM ${databaseNameAsId}.${threadsTableAsId}
          WHERE "threadId" = (
            SELECT "threadId" FROM "random_thread_id"
          )
          FOR NO KEY UPDATE 
        ), "update_vector_id" AS (
          UPDATE ${databaseNameAsId}.${threadsTableAsId}
          SET "threadCounter" = "threadCounter" + 1
          WHERE "threadId" = (
            SELECT "threadId" FROM "vector_id" LIMIT 1
          )
          RETURNING *
        ) INSERT INTO ${databaseNameAsId}.${eventsTableAsId}(
        "threadId",
        "threadCounter",
        "timestamp",
        "aggregateId",
        "aggregateVersion",
        "type",
        "payload",
        "eventSize"
        ) VALUES (
          (SELECT "threadId" FROM "vector_id" LIMIT 1),
          (SELECT "threadCounter" FROM "vector_id" LIMIT 1),
          ${+event.timestamp},
          ${serializedEvent},
          ${byteLength}
        )`);
      break;
    } catch (error) {
      const errorMessage = error != null && error.message != null ? error.message : '';
      const errorCode = error != null && error.code != null ? error.code : '';

      if (_constants.REMAINING_CONNECTIONS_REGEXP.test(errorMessage) || _constants.STATEMENT_TIMEOUT_CODE === errorCode) {
        continue;
      } else {
        throw error;
      }
    }
  }
};

var _default = saveEventOnly;
exports.default = _default;
//# sourceMappingURL=save-event-only.js.map